@@ -6,7 +6,7 @@ class ValueObject:
         return "<{}: {}>".format(self.__class__.__name__, self)
 
     def __eq__(self, other: Any) -> bool:
-        if isinstance(other, self.__class__):
+        if isinstance(other, type(self)) or isinstance(self, type(other)):
             return hash(self) == hash(other)
         else:
             return False
@@ -19,6 +19,7 @@ class Module(ValueObject):
     """
     A Python module.
     """
+    __slots__ = ("name",)
 
     def __init__(self, name: str) -> None:
         """
@@ -26,11 +27,14 @@ class Module(ValueObject):
             name: The fully qualified name of a Python module, e.g. 'package.foo.bar'.
         """
         self.name = name
-        self.package_name = name.split(".")[0]
 
     def __str__(self) -> str:
         return self.name
 
+    @property
+    def package_name(self) -> str:
+        return self.name.split(".")[0]
+
     @property
     def root(self) -> "Module":
         """
